/*
 * File:   lcd_pic.h
 * Author:  Ing. Peter Adamec
 * Company: MCU Slovel s.r.o.
 * Contact: mcu@mcu.sk
 *
 * Created a long time ago in a galaxy far, far away.
 */

#define uint8_t		unsigned char
#define _BV(bit) 	(1 << (bit))

#define _setbit(bit,port)	(port |=  _BV(bit))
#define _clearbit(bit,port)	(port &= ~_BV(bit))
#define _io_out(bit,port)	(port &= ~_BV(bit))
#define _io_in(bit,port)	(port |=  _BV(bit))

/* For STM32F1xx
#define _setbit(bit,port)	(port->BSRR |= _BV(bit))
#define _clearbit(bit,port)	(port->BRR |= _BV(bit))
#define _io_out(bit,port)	port &= ~(out_dir_neg<<bit); port |=(out_dir<<bit) 
#define _io_in(bit,port)	port &= ~(in_dir_neg<<bit); port |=(in_dir<<bit)
*/

#define LCD_PORT_D4	LATC
#define LCD_PORT_D5	LATC
#define LCD_PORT_D6	LATC
#define LCD_PORT_D7	LATC
#define LCD_PORT_RS	LATA
#define LCD_PORT_RW	LATA
#define LCD_PORT_E	LATC

#define LCD_DIR_D4	TRISC
#define LCD_DIR_D5	TRISC
#define LCD_DIR_D6	TRISC
#define LCD_DIR_D7	TRISC
#define LCD_DIR_RS	TRISA
#define LCD_DIR_RW	TRISA
#define LCD_DIR_E	TRISC

#define LCD_PIN_D4	PORTC
#define LCD_PIN_D5	PORTC
#define LCD_PIN_D6	PORTC
#define LCD_PIN_D7	PORTC
#define LCD_PIN_RS	PORTA
#define LCD_PIN_RW	PORTA
#define LCD_PIN_E	PORTC

#define LCD_D4		4
#define LCD_D5		3
#define LCD_D6		6
#define LCD_D7		7
#define LCD_E		5
#define	LCD_RW		4
#define LCD_RS		5

#define DIR_D4		4
#define DIR_D5		3
#define DIR_D6		6
#define DIR_D7		7
#define DIR_E		5
#define	DIR_RW		4
#define DIR_RS		5

#define riadok_1	0x00
#define riadok_2	0x40
#define riadok_3	0x14
#define riadok_4	0x54
#define disp_row	8		// 8 znakov v riadku
#define disp_col	2		// 2 riadky	

#define	light_PORT	PORTB
#define light_PIN	PORTB
#define light_DIR	TRISB
#define light		7

//PRE STM32
#define out_dir  0x1    // 10MHz toggle, push pull
#define out_dir_neg  0x8    // 10MHz toggle, push pull  neg 4b
#define in_dir   0x8    // pullup / pulldown (prislusny bit v ODR=H pullup, ODR=L pulldown)
#define in_dir_neg   0x1    // pullup / pulldown (prislusny bit v ODR=H pullup, ODR=L pulldown) 4b
//---------------------

void writeLCD (uint8_t);
void busy_dummy (void);
void lcd_init (void);
void lcd_putchar (uint8_t);
void lcd_clear (void);
void lcd_setddram (uint8_t);
void lcd_setposition (uint8_t, uint8_t);
void lcd_lighton(void);
void lcd_lighton(void);

